# Output Block Weights

1. 0 Reserved: Heading
2. 1 - 10 Reserved: Base
3. 11 - 20 Free
4. 21 - 30 Reserved: ARGS
5. 31 - 40 Free
6. 41 - 50 Reserved: ENV
7. 51 - 60 Free
8. 61 - 70 Reserved: User setup
9. 71 - 80 Free
10. 81 - 90 Reserved: Core APT package installation
11. 91 - 100 Free
12. 101 - 110 Reserved: Rust setup
13. 111 - 120 Free
14. 121 - 130 Reserved: Extra APT sources
15. 131 - 140 Free
16. 141 - 150 Reserved: APT package installation
17. 151 - 160 Free
18. 161 - 170 Reserved: Language-specific package installation
19. 171 - 180 Free
20. 181 - 190 Reserved: Content Copy
21. 191 - 200 Free
22. 201 - 210 Reserved: Pre-script copy data
22. 211 - 290 Reserved: User scripts
23. 291 - 300 Reserved: Post-script copy data
24. 301 - 310 Free
25. 311 - 320 Reserved: Services
26. 1001 - 1010 Known: JupyterLab Pack
27. 1021 - 1030 Known: XFCE4 Pack
28. 1041 - 1050 Known: CodeServer Pack
29. 1061 - 1070 Known: Ipykernel Pack
30. 1081 - 1090 Known: Irkernel Pack
31. 2001 - 3000 Recommended: User blocks
32. 9001 - 10000 Reserved: Run CMDs
